# ptest 用户文档

`user-guide/` 目录面向框架使用者，提供安装、入门和基础操作说明。

## 推荐阅读顺序

1. [basic-usage.md](basic-usage.md)
2. [mysql-full-lifecycle.md](mysql-full-lifecycle.md)

## 适用范围

这部分文档默认面向：

- 测试工程师
- 自动化测试使用者
- 需要快速上手 `ptest` CLI / Python API 的项目成员

## 当前说明

- SQLite 等轻量对象可以直接作为最小主线示例
- MySQL 全生命周期主案例当前基于 `host` runtime backend，需要执行环境支持真实服务运行

## 与其他目录的关系

- 如果你想直接使用框架，从这里开始
- 如果你要做二次开发，请转到 [../development/README.md](../development/README.md)
- 如果你要查看架构设计，请转到 [../architecture/README.md](../architecture/README.md)
- 如果你要看 API 细节，请转到 [../api/README.md](../api/README.md)
